@@ -39,6 +39,19 @@ SENSITIVE_HEADERS = ('X-Auth-Token',)
 osprofiler_web = importutils.try_import("osprofiler.web")
 
 
+def authenticated_fetcher(hc):
+    """A wrapper around the heat client object to fetch a template."""
+
+    def _do(*args, **kwargs):
+        if isinstance(hc.http_client, SessionClient):
+            method, url = args
+            return hc.http_client.request(url, method, **kwargs).content
+        else:
+            return hc.http_client.raw_request(*args, **kwargs).content
+
+    return _do
+
+
 def get_system_ca_file():
     """Return path to system default CA file."""
     # Standard CA file locations for Debian/Ubuntu, RedHat/Fedora,
@@ -54,7 +67,7 @@ def get_system_ca_file():
         if os.path.exists(ca):
             LOG.debug("Using ca file %s", ca)
             return ca
-    LOG.warn(_LW("System ca file could not be found."))
+    LOG.warning(_LW("System ca file could not be found."))
 
 
 class HTTPClient(object):
@@ -158,7 +171,7 @@ class HTTPClient(object):
             kwargs['headers'].setdefault('X-Auth-Url', self.auth_url)
         if self.region_name:
             kwargs['headers'].setdefault('X-Region-Name', self.region_name)
-        if self.include_pass and not 'X-Auth-Key' in kwargs['headers']:
+        if self.include_pass and 'X-Auth-Key' not in kwargs['headers']:
             kwargs['headers'].update(self.credentials_headers())
         if osprofiler_web:
             kwargs['headers'].update(osprofiler_web.get_trace_id_headers())
